@@ -229,7 +229,9 @@ GdkCursor*  gdk_cursor_new_from_name	 (GdkDisplay      *display,
 					  const gchar     *name);
 GdkDisplay* gdk_cursor_get_display	 (GdkCursor	  *cursor);
 #ifndef GDK_DISABLE_DEPRECATED
-GdkCursor*  gdk_cursor_ref               (GdkCursor       *cursor);
+GDK_DEPRECATED_FOR(g_object_ref)
+GdkCursor * gdk_cursor_ref               (GdkCursor       *cursor);
+GDK_DEPRECATED_FOR(g_object_unref)
 void        gdk_cursor_unref             (GdkCursor       *cursor);
 #endif
 GdkPixbuf*  gdk_cursor_get_image         (GdkCursor       *cursor);
