@@ -503,6 +503,7 @@ GdkVisual *   gdk_window_get_visual            (GdkWindow     *window);
 GdkScreen *   gdk_window_get_screen            (GdkWindow     *window);
 GdkDisplay *  gdk_window_get_display           (GdkWindow     *window);
 #ifndef GDK_MULTIDEVICE_SAFE
+GDK_DEPRECATED_FOR(gdk_device_get_window_at_position)
 GdkWindow*    gdk_window_at_pointer            (gint          *win_x,
                                                 gint          *win_y);
 #endif /* GDK_MULTIDEVICE_SAFE */
@@ -710,10 +711,11 @@ void          gdk_window_get_frame_extents (GdkWindow     *window,
                                             GdkRectangle  *rect);
 
 #ifndef GDK_MULTIDEVICE_SAFE
-GdkWindow*    gdk_window_get_pointer	 (GdkWindow	  *window,
-					  gint		  *x,
-					  gint		  *y,
-					  GdkModifierType *mask);
+GDK_DEPRECATED_FOR(gdk_window_get_device_position)
+GdkWindow *   gdk_window_get_pointer     (GdkWindow       *window,
+                                          gint            *x,
+                                          gint            *y,
+                                          GdkModifierType *mask);
 #endif /* GDK_MULTIDEVICE_SAFE */
 GdkWindow *   gdk_window_get_device_position (GdkWindow       *window,
                                               GdkDevice       *device,
