@@ -81,13 +81,15 @@ GtkWidget*     gtk_button_new               (void);
 GtkWidget*     gtk_button_new_with_label    (const gchar    *label);
 GtkWidget*     gtk_button_new_from_stock    (const gchar    *stock_id);
 GtkWidget*     gtk_button_new_with_mnemonic (const gchar    *label);
-#ifndef GTK_DISABLE_DEPRECATED
-void           gtk_button_pressed           (GtkButton      *button);
-void           gtk_button_released          (GtkButton      *button);
-#endif
 void           gtk_button_clicked           (GtkButton      *button);
 #ifndef GTK_DISABLE_DEPRECATED
+GDK_DEPRECATED
+void           gtk_button_pressed           (GtkButton      *button);
+GDK_DEPRECATED
+void           gtk_button_released          (GtkButton      *button);
+GDK_DEPRECATED
 void           gtk_button_enter             (GtkButton      *button);
+GDK_DEPRECATED
 void           gtk_button_leave             (GtkButton      *button);
 #endif
 
@@ -96,7 +98,7 @@ void                  gtk_button_set_relief         (GtkButton      *button,
 GtkReliefStyle        gtk_button_get_relief         (GtkButton      *button);
 void                  gtk_button_set_label          (GtkButton      *button,
 						     const gchar    *label);
-G_CONST_RETURN gchar *gtk_button_get_label          (GtkButton      *button);
+const gchar *         gtk_button_get_label          (GtkButton      *button);
 void                  gtk_button_set_use_underline  (GtkButton      *button,
 						     gboolean        use_underline);
 gboolean              gtk_button_get_use_underline  (GtkButton      *button);
@@ -121,16 +123,6 @@ GtkPositionType       gtk_button_get_image_position (GtkButton      *button);
 
 GdkWindow*            gtk_button_get_event_window   (GtkButton      *button);
 
-void _gtk_button_set_depressed             (GtkButton          *button,
-					    gboolean            depressed);
-void _gtk_button_paint                     (GtkButton          *button,
-                                            cairo_t            *cr,
-                                            int                 width,
-                                            int                 height,
-					    GtkStateType        state_type,
-					    GtkShadowType       shadow_type,
-					    const gchar        *main_detail,
-					    const gchar        *default_detail);
 
 G_END_DECLS
 
