@@ -24,13 +24,15 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
 #ifndef __GTK_HPANED_H__
 #define __GTK_HPANED_H__
 
+#ifndef GTK_DISABLE_DEPRECATED
+
 #include <gtk/gtkpaned.h>
 
 G_BEGIN_DECLS
@@ -56,9 +58,13 @@ struct _GtkHPanedClass
   GtkPanedClass parent_class;
 };
 
-GType      gtk_hpaned_get_type (void) G_GNUC_CONST;
-GtkWidget *gtk_hpaned_new      (void);
+
+GType       gtk_hpaned_get_type (void) G_GNUC_CONST;
+GDK_DEPRECATED_FOR(gtk_paned_new)
+GtkWidget * gtk_hpaned_new      (void);
 
 G_END_DECLS
 
+#endif
+
 #endif /* __GTK_HPANED_H__ */
