@@ -8,7 +8,7 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
@@ -51,12 +51,30 @@ typedef struct _GtkRcStyleClass GtkRcStyleClass;
 
 typedef enum
 {
-  GTK_RC_FG		= 1 << 0,
-  GTK_RC_BG		= 1 << 1,
-  GTK_RC_TEXT		= 1 << 2,
-  GTK_RC_BASE		= 1 << 3
+  GTK_RC_FG             = 1 << 0,
+  GTK_RC_BG             = 1 << 1,
+  GTK_RC_TEXT           = 1 << 2,
+  GTK_RC_BASE           = 1 << 3
 } GtkRcFlags;
 
+/**
+ * GtkRcStyle:
+ * @name:
+ * @bg_pixmap_name:
+ * @font_desc:
+ * @color_flags:
+ * @fg:
+ * @bg:
+ * @text:
+ * @base:
+ * @xthickness:
+ * @ythickness:
+ *
+ * The #GtkRcStyle structure is used to represent a set
+ * of information about the appearance of a widget.
+ * This can later be composited together with other
+ * #GtkRcStyle structures to form a #GtkStyle.
+ */
 struct _GtkRcStyle
 {
   GObject parent_instance;
@@ -84,7 +102,7 @@ struct _GtkRcStyle
 
   GSList *icon_factories;
 
-  guint engine_specified : 1;	/* The RC file specified the engine */
+  guint engine_specified : 1;   /* The RC file specified the engine */
 };
 
 struct _GtkRcStyleClass
@@ -103,14 +121,14 @@ struct _GtkRcStyleClass
    * the token it expected but didn't get.
    */
   guint     (*parse)  (GtkRcStyle   *rc_style,
-		       GtkSettings  *settings,
-		       GScanner     *scanner);
+                       GtkSettings  *settings,
+                       GScanner     *scanner);
 
   /* Combine RC style data from src into dest. If overridden, this
    * function should chain to the parent.
    */
   void      (*merge)  (GtkRcStyle *dest,
-		       GtkRcStyle *src);
+                       GtkRcStyle *src);
 
   /* Create an empty style suitable to this RC style
    */
@@ -131,39 +149,107 @@ gboolean  _gtk_rc_match_widget_class     (GSList       *list,
                                           gchar        *path_reversed);
 
 #if !defined(GTK_DISABLE_DEPRECATED) || defined(GTK_COMPILATION)
-
-void      gtk_rc_add_default_file	(const gchar *filename);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+void      gtk_rc_add_default_file       (const gchar *filename);
+GDK_DEPRECATED_FOR(GtkStyleContext)
 void      gtk_rc_set_default_files      (gchar **filenames);
+GDK_DEPRECATED_FOR(GtkStyleContext)
 gchar**   gtk_rc_get_default_files      (void);
-GtkStyle* gtk_rc_get_style		(GtkWidget   *widget);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+GtkStyle* gtk_rc_get_style              (GtkWidget   *widget);
+GDK_DEPRECATED_FOR(GtkStyleContext)
 GtkStyle* gtk_rc_get_style_by_paths     (GtkSettings *settings,
-					 const char  *widget_path,
-					 const char  *class_path,
-					 GType        type);
+                                         const char  *widget_path,
+                                         const char  *class_path,
+                                         GType        type);
 
+GDK_DEPRECATED_FOR(GtkStyleContext)
 gboolean gtk_rc_reparse_all_for_settings (GtkSettings *settings,
-					  gboolean     force_load);
+                                          gboolean     force_load);
+GDK_DEPRECATED_FOR(GtkStyleContext)
 void     gtk_rc_reset_styles             (GtkSettings *settings);
 
+GDK_DEPRECATED_FOR(GtkStyleContext)
 gchar*   gtk_rc_find_pixmap_in_path (GtkSettings  *settings,
-				     GScanner     *scanner,
-				     const gchar  *pixmap_file);
+                                     GScanner     *scanner,
+                                     const gchar  *pixmap_file);
 
-void	  gtk_rc_parse			(const gchar *filename);
-void	  gtk_rc_parse_string		(const gchar *rc_string);
-gboolean  gtk_rc_reparse_all		(void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+void     gtk_rc_parse                   (const gchar *filename);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+void      gtk_rc_parse_string           (const gchar *rc_string);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gboolean  gtk_rc_reparse_all            (void);
 
 GType       gtk_rc_style_get_type   (void) G_GNUC_CONST;
+GDK_DEPRECATED_FOR(GtkStyleContext)
 GtkRcStyle* gtk_rc_style_new        (void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
 GtkRcStyle* gtk_rc_style_copy       (GtkRcStyle *orig);
 
-gchar*		gtk_rc_find_module_in_path	(const gchar 	*module_file);
-gchar*		gtk_rc_get_theme_dir		(void);
-gchar*		gtk_rc_get_module_dir		(void);
-gchar*		gtk_rc_get_im_module_path	(void);
-gchar*		gtk_rc_get_im_module_file	(void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gchar*      gtk_rc_find_module_in_path (const gchar *module_file);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gchar*      gtk_rc_get_theme_dir       (void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gchar*      gtk_rc_get_module_dir      (void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gchar*      gtk_rc_get_im_module_path  (void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+gchar*      gtk_rc_get_im_module_file  (void);
 
 /* private functions/definitions */
+
+/**
+ * GtkRcTokenType:
+ * @GTK_RC_TOKEN_INVALID:
+ * @GTK_RC_TOKEN_INCLUDE:
+ * @GTK_RC_TOKEN_NORMAL:
+ * @GTK_RC_TOKEN_ACTIVE:
+ * @GTK_RC_TOKEN_PRELIGHT:
+ * @GTK_RC_TOKEN_SELECTED:
+ * @GTK_RC_TOKEN_INSENSITIVE:
+ * @GTK_RC_TOKEN_FG:
+ * @GTK_RC_TOKEN_BG:
+ * @GTK_RC_TOKEN_TEXT:
+ * @GTK_RC_TOKEN_BASE:
+ * @GTK_RC_TOKEN_XTHICKNESS:
+ * @GTK_RC_TOKEN_YTHICKNESS:
+ * @GTK_RC_TOKEN_FONT:
+ * @GTK_RC_TOKEN_FONTSET:
+ * @GTK_RC_TOKEN_FONT_NAME:
+ * @GTK_RC_TOKEN_BG_PIXMAP:
+ * @GTK_RC_TOKEN_PIXMAP_PATH:
+ * @GTK_RC_TOKEN_STYLE:
+ * @GTK_RC_TOKEN_BINDING:
+ * @GTK_RC_TOKEN_BIND:
+ * @GTK_RC_TOKEN_WIDGET:
+ * @GTK_RC_TOKEN_WIDGET_CLASS:
+ * @GTK_RC_TOKEN_CLASS:
+ * @GTK_RC_TOKEN_LOWEST:
+ * @GTK_RC_TOKEN_GTK:
+ * @GTK_RC_TOKEN_APPLICATION:
+ * @GTK_RC_TOKEN_THEME:
+ * @GTK_RC_TOKEN_RC:
+ * @GTK_RC_TOKEN_HIGHEST:
+ * @GTK_RC_TOKEN_ENGINE:
+ * @GTK_RC_TOKEN_MODULE_PATH:
+ * @GTK_RC_TOKEN_IM_MODULE_PATH:
+ * @GTK_RC_TOKEN_IM_MODULE_FILE:
+ * @GTK_RC_TOKEN_STOCK:
+ * @GTK_RC_TOKEN_LTR:
+ * @GTK_RC_TOKEN_RTL:
+ * @GTK_RC_TOKEN_COLOR:
+ * @GTK_RC_TOKEN_UNBIND:
+ * @GTK_RC_TOKEN_LAST:
+ *
+ * The #GtkRcTokenType enumeration represents the tokens
+ * in the RC file. It is exposed so that theme engines
+ * can reuse these tokens when parsing the theme-engine
+ * specific portions of a RC file.
+ *
+ * Deprecated: 3.0: Use #GtkCssProvider instead.
+ */
 typedef enum {
   GTK_RC_TOKEN_INVALID = G_TOKEN_LAST,
   GTK_RC_TOKEN_INCLUDE,
@@ -207,16 +293,21 @@ typedef enum {
   GTK_RC_TOKEN_LAST
 } GtkRcTokenType;
 
-GScanner* gtk_rc_scanner_new	(void);
-guint	  gtk_rc_parse_color	(GScanner	     *scanner,
-				 GdkColor	     *color);
-guint	  gtk_rc_parse_color_full (GScanner	     *scanner,
+GDK_DEPRECATED_FOR(GtkStyleContext)
+GScanner* gtk_rc_scanner_new    (void);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+guint     gtk_rc_parse_color    (GScanner            *scanner,
+                                 GdkColor            *color);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+guint     gtk_rc_parse_color_full (GScanner          *scanner,
                                    GtkRcStyle        *style,
-				   GdkColor	     *color);
-guint	  gtk_rc_parse_state	(GScanner	     *scanner,
-				 GtkStateType	     *state);
-guint	  gtk_rc_parse_priority	(GScanner	     *scanner,
-				 GtkPathPriorityType *priority);
+                                   GdkColor          *color);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+guint     gtk_rc_parse_state    (GScanner            *scanner,
+                                 GtkStateType        *state);
+GDK_DEPRECATED_FOR(GtkStyleContext)
+guint     gtk_rc_parse_priority (GScanner            *scanner,
+                                 GtkPathPriorityType *priority);
 
 #endif
 
