@@ -165,6 +165,11 @@ gtk_css_provider_error_get_type (void)
     if (G_UNLIKELY(etype == 0)) {
         static const GEnumValue values[] = {
             { GTK_CSS_PROVIDER_ERROR_FAILED, "GTK_CSS_PROVIDER_ERROR_FAILED", "failed" },
+            { GTK_CSS_PROVIDER_ERROR_SYNTAX, "GTK_CSS_PROVIDER_ERROR_SYNTAX", "syntax" },
+            { GTK_CSS_PROVIDER_ERROR_IMPORT, "GTK_CSS_PROVIDER_ERROR_IMPORT", "import" },
+            { GTK_CSS_PROVIDER_ERROR_NAME, "GTK_CSS_PROVIDER_ERROR_NAME", "name" },
+            { GTK_CSS_PROVIDER_ERROR_DEPRECATED, "GTK_CSS_PROVIDER_ERROR_DEPRECATED", "deprecated" },
+            { GTK_CSS_PROVIDER_ERROR_UNKNOWN_VALUE, "GTK_CSS_PROVIDER_ERROR_UNKNOWN_VALUE", "unknown-value" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GtkCssProviderError"), values);
@@ -172,6 +177,28 @@ gtk_css_provider_error_get_type (void)
     return etype;
 }
 
+/* enumerations from "gtkcsssection.h" */
+GType
+gtk_css_section_type_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GTK_CSS_SECTION_DOCUMENT, "GTK_CSS_SECTION_DOCUMENT", "document" },
+            { GTK_CSS_SECTION_IMPORT, "GTK_CSS_SECTION_IMPORT", "import" },
+            { GTK_CSS_SECTION_COLOR_DEFINITION, "GTK_CSS_SECTION_COLOR_DEFINITION", "color-definition" },
+            { GTK_CSS_SECTION_BINDING_SET, "GTK_CSS_SECTION_BINDING_SET", "binding-set" },
+            { GTK_CSS_SECTION_RULESET, "GTK_CSS_SECTION_RULESET", "ruleset" },
+            { GTK_CSS_SECTION_SELECTOR, "GTK_CSS_SECTION_SELECTOR", "selector" },
+            { GTK_CSS_SECTION_DECLARATION, "GTK_CSS_SECTION_DECLARATION", "declaration" },
+            { GTK_CSS_SECTION_VALUE, "GTK_CSS_SECTION_VALUE", "value" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GtkCssSectionType"), values);
+    }
+    return etype;
+}
+
 /* enumerations from "gtkdebug.h" */
 GType
 gtk_debug_flag_get_type (void)
@@ -1159,6 +1186,7 @@ gtk_region_flags_get_type (void)
             { GTK_REGION_ODD, "GTK_REGION_ODD", "odd" },
             { GTK_REGION_FIRST, "GTK_REGION_FIRST", "first" },
             { GTK_REGION_LAST, "GTK_REGION_LAST", "last" },
+            { GTK_REGION_ONLY, "GTK_REGION_ONLY", "only" },
             { GTK_REGION_SORTED, "GTK_REGION_SORTED", "sorted" },
             { 0, NULL, NULL }
         };
